<?php
/**
 * starthub Filters extends WordPress Filters by registering sub filters if it is told to do so.
 *
 * @package API\Filters
 */

/**
 * Hooks a function or method to a specific filter action.
 *
 * This function is similar to {@link http://codex.WordPress.org/Function_Reference/add_filter add_filter()}
 * with the exception that it accepts a $callback argument which is used to automatically create an
 * anonymous function.
 *
 * @since 1.0.0
 *
 * @param string   $id       The filter ID.
 * @param callback $callback The name of the function you wish to be called. Inline content will automatically
 *                           create an anonymous function.
 * @param int      $priority Optional. Used to specify the order in which the functions
 *                           associated with a particular action are executed. Default 10.
 *                           Lower numbers correspond with earlier execution,
 *                           and functions with the same priority are executed
 *                           in the order in which they were added to the action.
 * @param int      $args     Optional. The number of arguments the function accepts. Default 1.
 *
 * @return bool Will always return true.
 */
function starthub_add_filter( $id, $callback, $priority = 10, $args = 1 ) {

	if ( is_callable( $callback ) )
		return add_filter( $id, $callback, $priority, $args );

	return starthub_tt_add_anonymous_filter( $id, $callback, $priority, $args );

}


/**
 * Call the functions added to a filter hook.
 *
 * This function is similar to {@link http://codex.WordPress.org/Function_Reference/apply_filters apply_filters()}
 * with the exception of creating sub-hooks if it is told to do so.
 *
 * Sub-hooks must be set in square brackets as part of the filter id argument. Sub-hooks are cascaded
 * in a similar way to CSS classes. Maximum 3 sub-hooks allowed.
 *
 * @since 1.0.0
 *
 * @param string $id    A unique string used as a reference. Sub-hook(s) must be set in square brackets. Each sub-
 *                      hook will create a filter. For instance, 'hook[_sub_hook]' will create a
 *                      'hook_name' filter as well as a 'hook[_sub_hook]' filter. The id may contain
 *                      multiple sub hooks such as 'hook[_sub_hook][_sub_sub_hook]'.
 *                      In this case, four filters will be created 'hook', 'hook[_sub_hook]',
 *                      'hook[_sub_sub_hook]' and 'hook[_sub_hook][_sub_sub_hook]'. Sub-hooks
 *                      always run the parent filter first, so a filter set to the parent will apply
 *                      to all sub-hooks. Maximum 3 sub-hooks allowed.
 * @param mixed  $value The value on which the filters hooked to <tt>$id</tt> are applied to it.
 * @param mixed  $var   Additional variables passed to the functions hooked to <tt>$id</tt>.
 *
 * @return mixed The filtered value after all hooked functions are applied to it.
 */
function starthub_apply_filters( $id, $value ) {

	$args = func_get_args();

	// Return simple filter if no sub-hook is set.
	if ( !preg_match_all( '#\[(.*?)\]#', $args[0], $matches ) )
		return call_user_func_array( 'apply_filters', $args );

	$prefix = current( explode( '[', $args[0] ) );
	$variable_prefix = $prefix;
	$suffix = preg_replace( '/^.*\]\s*/', '', $args[0] );

	// Base filter.
	$args[0] = $prefix . $suffix;
	$value = call_user_func_array( 'apply_filters', $args );

	foreach ( $matches[0] as $i => $subhook ) {

		$variable_prefix = $variable_prefix . $subhook;
		$levels = array( $prefix . $subhook . $suffix );

		// Cascade sub-hooks.
		if ( $i > 0 ) {

			$levels[] = str_replace( $subhook, '', $id );
			$levels[] = $variable_prefix . $suffix;

		}

		// Apply sub-hooks.
		foreach ( $levels as $level ) {

			$args[0] = $level;
			$args[1] = $value;
			$value = call_user_func_array( 'apply_filters', $args );

			// Apply filter whithout square brackets for backwards compatibility.
			$args[0] = preg_replace( '#(\[|\])#', '', $args[0] );
			$args[1] = $value;
			$value = call_user_func_array( 'apply_filters', $args );

		}

	}


	return $value;

}


/**
 * Check if any filter has been registered for a hook.
 *
 * This function is similar to {@link http://codex.WordPress.org/Function_Reference/has_filters has_filters()}
 * with the exception of checking sub-hooks if it is told to do so.
 *
 * @since 1.0.0
 *
 * @param string   $id       	  The filter ID.
 * @param callback|bool $callback Optional. The callback to check for. Default false.
 *
 * @return bool|int If $callback is omitted, returns boolean for whether the hook has
 *                  anything registered. When checking a specific function, the priority of that
 *                  hook is returned, or false if the function is not attached. When using the
 *                  $callback argument, this function may return a non-boolean value
 *                  that evaluates to false (e.g. 0), so use the === operator for testing the
 *                  return value.
 */
function starthub_has_filters( $id, $callback = false ) {

	// Check simple filter if no subhook is set.
	if ( !preg_match_all( '#\[(.*?)\]#', $id, $matches ) )
		return has_filter( $id, $callback );

	$prefix = current( explode( '[', $id ) );
	$variable_prefix = $prefix;
	$suffix = preg_replace( '/^.*\]\s*/', '', $id );

	// Check base filter.
	if ( has_filter( $prefix . $suffix, $callback ) )
		return true;

	foreach ( $matches[0] as $i => $subhook ) {

		$variable_prefix = $variable_prefix . $subhook;
		$levels = array( $prefix . $subhook . $suffix );

		// Cascade sub-hooks.
		if ( $i > 0 ) {

			$levels[] = str_replace( $subhook, '', $id );
			$levels[] = $variable_prefix . $suffix;

		}

		// Apply sub-hooks.
		foreach ( $levels as $level ) {

			if ( has_filter( $level, $callback ) )
				return true;

			// Check filter whithout square brackets for backwards compatibility.
			if ( has_filter( preg_replace( '#(\[|\])#', '', $level ), $callback ) )
				return true;

		}

	}

	return false;

}


/**
 * Add anonymous callback using a class since php 5.2 is still supported.
 *
 * @ignore
 */
function starthub_tt_add_anonymous_filter( $id, $callback, $priority = 10, $args = 1 ) {

        load_template( starthub_API_PATH . 'filters/class.php', true );

	new starthub_tt_Anonymous_Filters( $id, $callback, $priority, $args );

}
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581327712&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        